Welcome
=======
Tomotok provides inversions methods and framework easing computation of inversion for tokamak data, i.e. assuming toroidal symmetry.
It aims at providing multiple inversion algorithms to ease tomography usage by the fusion community. The package is released as open-source for a better transparency of the code, for reproducibility of the results as well as to allow a broader user usage.

Contributors
------------
* Jakub Svoboda (coding, algorithms)
* Jordan Cavalier (algorithms, visible cameras)
* Ondrej Ficker (algorithms, math)
* Martin Imrisek (algorithms, coding)

Citations
---------
If used for a scientific publication, please cite the software using the references below together with references for inversion methods used. These can be found in section :doc:`inversions/inversions`.

"J. Svoboda, J. Cavalier, O.Ficker, M. Imrisek, J. Mlynar and M. Hron, *Tomotok: python package for tomography of tokamak plasma radiation*, 4th ECPD Conference (2021), Journal of Instrumentation"